<p>
<br>  Digital Innovation One, Curso em Video, Phytonando
<br>  Descomplicando a criacao de pacotes em Python
<br>  Aluna: Mirian Ajiki Molicawa
<br>  Instrutores: Karina Kato, Gustavo Guanabara e Caio Sampaio
<br>  Data: 16/10/2022 
</p>

<h2> Tecnologias </h2>
<br> - [x] Visual Studio Code
<br> - [x] Phyton V3 
<br> - [x] [Teste Pypi](https://pypi.org/)
<br> - [x] [Produção Pypi](https://pypi.org/)
</p>

<br> Pypi: Repositorio publico oficial de pacotes
<br> Wheel e Sdist: sao tipos de distribuicoes
<br> Setuptools: pacote usado em setup.py para gerar as distribuicoes
<br> Twine: pacote usado para subir as distribuicoes no repositorio Pypi

</p>

<br> Projeto: pacote_preco
<br> Pacote: valor_preco
<br> Módulos: dado, preco
<br> Programa: teste

</p>

<h2> Preco </h2>
<br> Tem as funcoes: aumentar, diminuir, dobro e metade do valor do preço
<br> - Parametro Preço: O preço a ser calculado
<br> - Parametro Taxa: porcentagem do aumento e diminuicao
<br> - Parametro Formato: Sendo verdadeiro traz formatado a casa decimal
<br> - Return: Traz o valor calculado
<br> - formatacao_valor: insercao do R$ e 2 casas decimais separadas por virgula
<br> - resumo: impressao na tela dos valores resumidos
</p>

<h2> Dado </h2>
<br> Tem as funcoes de validacao para aceitar somente valores numericos.
<br> leia_valor_moeda: aceita numeros inteiros e reais separados com virgula ou ponto. 
<br> leia_valor_inteiro: aceita numeros inteiros e rejeita caracteres.
<br> leia_valor_float: valida se entrada em numeros reais.
</p>

<h2> Teste</h2>
<br> Atraves da importacao dos pacotes e modulos, calcula-se o valor do preço informado.
